@@ -1,7 +1,7 @@
 //
 // anitech.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,10 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
-
 class AnitechTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AnitechTV1(
     unsigned int index);
@@ -39,6 +39,8 @@ public:
 
 class AnitechVCR1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   AnitechVCR1(
     unsigned int index);
