@@ -1,7 +1,7 @@
 //
 // frontech.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -46,6 +46,12 @@ void FrontechTV1::populateProtocol(
 
   threadableProtocol = new ProtonProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x02, 8);
 
   addKey("CH+", ChannelUp_Key, 0x01, 8);
@@ -102,6 +108,12 @@ void FrontechTV2::populateProtocol(
 
   threadableProtocol = new NECXProtocol(guiObject, index, false);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x0E0E, 16);
 
   addKey("1", One_Key, 0x00, 8);
