@@ -25,6 +25,7 @@
 #include "protocols/necxprotocol.h"
 #include "protocols/necprotocol.h"
 #include "protocols/protonprotocol.h"
+#include "protocols/blaupunktprotocol.h"
 #include <QComboBox>
 
 
@@ -844,6 +845,77 @@ void GrundigTV5::populateProtocol(
 }
 
 
+GrundigTV6::GrundigTV6(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "TV Keyset 6",
+      Grundig_Make,
+      TV_Panels,
+      index)
+{
+}
+
+
+void GrundigTV6::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new BlaupunktProtocol(guiObject, index);
+
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
+  setPreData(0x0, 2);  // Device 0
+
+  addKey("select", Select_Key, 0x01, 7);
+  addKey("enter", Enter_Key, 0x01, 7);
+  addKey("mute", Mute_Key, 0x03, 7);
+  addKey("rewind", Rewind_Key, 0x03, 7);
+  addKey("power", Power_Key, 0x05, 7);
+  addKey("program/guide (TV-G)", Guide_Key, 0x09, 7);
+  addKey("fast fwd", FastForward_Key, 0x09, 7);
+  addKey("vol up", VolumeUp_Key, 0x11, 7);
+  addKey("right arrow (+)", Right_Key, 0x11, 7);
+  addKey("vol down", VolumeDown_Key, 0x13, 7);
+  addKey("left arrow (-)", Left_Key, 0x13, 7);
+  addKey("0", Zero_Key, 0x21, 7);
+  addKey("AV List", Input_Key, 0x21, 7);
+  addKey("1", One_Key, 0x23, 7);
+  addKey("2", Two_Key, 0x25, 7);
+  addKey("3", Three_Key, 0x27, 7);
+  addKey("4", Four_Key, 0x29, 7);
+  addKey("5", Five_Key, 0x2B, 7);
+  addKey("6", Six_Key, 0x2D, 7);
+  addKey("7", Seven_Key, 0x2F, 7);
+  addKey("8", Eight_Key, 0x31, 7);
+  addKey("9", Nine_Key, 0x33, 7);
+  addKey("Screen Size", AspectRatio_Key, 0x35, 7);
+  addKey("REC", Record_Key, 0x35, 7);
+  addKey("YELLOW", Yellow_Key, 0x35, 7);
+  addKey("channel up", ChannelUp_Key, 0x55, 7);
+  addKey("up arrow (P+)", Up_Key, 0x55, 7);
+  addKey("channel down", ChannelDown_Key, 0x57, 7);
+  addKey("down arrow (P-)", Down_Key, 0x57, 7);
+  addKey("menu", Menu_Key, 0x5B, 7);
+  addKey("exit", Exit_Key, 0x5D, 7);
+  addKey("stop", Stop_Key, 0x5D, 7);
+  addKey("BLUE", Blue_Key, 0x5D, 7);
+  addKey("display/info", Info_Key, 0x75, 7);
+  addKey("RED", Red_Key, 0x75, 7);
+  addKey("pause", Pause_Key, 0x77, 7);
+  addKey("play", Play_Key, 0x7D, 7);
+  addKey("GREEN", Green_Key, 0x7D, 7);
+}
+
+
 GrundigDVD1::GrundigDVD1(
   unsigned int index)
   : PIRKeysetMetaData(
