@@ -193,6 +193,19 @@ public:
 };
 
 
+class GrundigTV6: public PIRKeysetMetaData
+{
+  Q_OBJECT
+
+public:
+  GrundigTV6(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+
 class GrundigDVD1: public PIRKeysetMetaData
 {
   Q_OBJECT
