@@ -87,7 +87,7 @@ public:
     QObject *guiObject);
 
   virtual void populateInputList(
-    QComboBox *cb);
+    QComboBox *cb) const;
 };
 
 class HitachiProjector: public PIRKeysetMetaData
