@@ -1019,7 +1019,7 @@ PanasonicAudio2::PanasonicAudio2(
   : PIRKeysetMetaData(
       "Audio Keyset 2",
       Panasonic_Make,
-      Receiver_Panels | MediaRecord_Panels,
+      Receiver_Panels,
       index)
 {
 }
@@ -1139,7 +1139,7 @@ PanasonicAudio3::PanasonicAudio3(
   : PIRKeysetMetaData(
       "Audio Keyset 3",
       Panasonic_Make,
-      Receiver_Panels | MediaRecord_Panels,
+      Receiver_Panels,
       index)
 {
 }
@@ -1206,6 +1206,311 @@ void PanasonicAudio3::populateInputList(
 }
 
 
+PanasonicAudio4::PanasonicAudio4(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "Audio Keyset 4",
+      Panasonic_Make,
+      Receiver_Panels,
+      index)
+{
+}
+
+
+void PanasonicAudio4::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new PanasonicProtocol(guiObject, index);
+
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
+  setPreData(0x2002, 16);
+
+  addPanasonicKey("VolumeUp", VolumeUp_Key, 0xA0, 0x00, 0x20);
+  addPanasonicKey("VolumeDown", VolumeDown_Key, 0xA0, 0x00, 0x21);
+  addPanasonicKey("Mute", Mute_Key, 0xA0, 0x00, 0x32);
+  addPanasonicKey("InputIpod", PCInput_Key, 0xA0, 0x00, 0xA7);
+
+  addPanasonicKey("InputTuner", TunerInput_Key, 0xA0, 0x04, 0xA4);
+
+  addPanasonicKey("PowerToggle", Power_Key, 0xA0, 0x1C, 0x3D);
+
+  addPanasonicKey("Stop", Stop_Key, 0xB0, 0x00, 0x00);
+  addPanasonicKey("Rewind", Rewind_Key, 0xB0, 0x00, 0x04);
+  addPanasonicKey("TuneDown", ChannelDown_Key, 0xB0, 0x00, 0x04);
+  addPanasonicKey("FastForward", FastForward_Key, 0xB0, 0x00, 0x05);
+  addPanasonicKey("TuneUp", ChannelUp_Key, 0xB0, 0x00, 0x05);
+  addPanasonicKey("Pause", Pause_Key, 0xB0, 0x00, 0x06);
+  addPanasonicKey("Play", Play_Key, 0xB0, 0x00, 0x0A);
+  addPanasonicKey("1", One_Key, 0xB0, 0x00, 0x10);
+  addPanasonicKey("2", Two_Key, 0xB0, 0x00, 0x11);
+  addPanasonicKey("3", Three_Key, 0xB0, 0x00, 0x12);
+  addPanasonicKey("4", Four_Key, 0xB0, 0x00, 0x13);
+  addPanasonicKey("5", Five_Key, 0xB0, 0x00, 0x14);
+  addPanasonicKey("6", Six_Key, 0xB0, 0x00, 0x15);
+  addPanasonicKey("7", Seven_Key, 0xB0, 0x00, 0x16);
+  addPanasonicKey("8", Eight_Key, 0xB0, 0x00, 0x17);
+  addPanasonicKey("9", Nine_Key, 0xB0, 0x00, 0x18);
+  addPanasonicKey("0", Zero_Key, 0xB0, 0x00, 0x19);
+  addPanasonicKey("InputBdSd", DVDInput_Key, 0xB0, 0x00, 0x2C);
+  addPanasonicKey("Audio", Unmapped_Key, 0xB0, 0x00, 0x33);
+  addPanasonicKey("PresetPrev", Unmapped_Key, 0xB0, 0x00, 0x49);
+  addPanasonicKey("PreviousTrack", Unmapped_Key, 0xB0, 0x00, 0x49);
+  addPanasonicKey("PresetNext", Unmapped_Key, 0xB0, 0x00, 0x4A);
+  addPanasonicKey("NextTrack", Unmapped_Key, 0xB0, 0x00, 0x4A);
+  addPanasonicKey("Status", Unmapped_Key, 0xB0, 0x00, 0x5F);
+  addPanasonicKey("SubMenu", Unmapped_Key, 0xB0, 0x00, 0x80);
+  addPanasonicKey("Return", Back_Key, 0xB0, 0x00, 0x81);
+  addPanasonicKey("Select/Ok", Select_Key, 0xB0, 0x00, 0x82);
+  addPanasonicKey("Cancel", Exit_Key, 0xB0, 0x00, 0x83);
+  addPanasonicKey("DirectionUp", Up_Key, 0xB0, 0x00, 0x85);
+  addPanasonicKey("DirectionDown", Down_Key, 0xB0, 0x00, 0x86);
+  addPanasonicKey("DirectionLeft", Left_Key, 0xB0, 0x00, 0x87);
+  addPanasonicKey("DirectionRight", Right_Key, 0xB0, 0x00, 0x88);
+  addPanasonicKey("Display", Info_Key, 0xB0, 0x00, 0x92);
+  addPanasonicKey("Sleep", Sleep_Key, 0xB0, 0x00, 0x92);
+  addPanasonicKey("DirectNavigator", Unmapped_Key, 0xB0, 0x00, 0x9B);
+  addPanasonicKey("TopMenu", DiscMenu_Key, 0xB0, 0x00, 0x9B);
+
+  addPanasonicKey("Blue", Blue_Key, 0xB0, 0x01, 0x40);
+  addPanasonicKey("Red", Red_Key, 0xB0, 0x01, 0x41);
+  addPanasonicKey("Green", Green_Key, 0xB0, 0x01, 0x42);
+  addPanasonicKey("Yellow", Yellow_Key, 0xB0, 0x01, 0x43);
+  addPanasonicKey("PopUpMenu", Menu_Key, 0xB0, 0x01, 0x50);
+  addPanasonicKey("Exit", Unmapped_Key, 0xB0, 0x01, 0x51);
+  addPanasonicKey("VieraCast", Unmapped_Key, 0xB0, 0x01, 0x59);
+  addPanasonicKey("#", Unmapped_Key, 0xB0, 0x01, 0x5A);
+}
+
+
+void PanasonicAudio4::populateInputList(
+  QComboBox *cb) const
+{
+  cb->clear();
+
+  cb->addItem("iPod", QVariant(PCInput_Key));
+  cb->addItem("Tuner", QVariant(TunerInput_Key));
+  cb->addItem("BD / SD Disc", QVariant(DVDInput_Key));
+}
+
+
+PanasonicAudio5::PanasonicAudio5(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "Audio Keyset 5",
+      Panasonic_Make,
+      Receiver_Panels,
+      index)
+{
+}
+
+
+void PanasonicAudio5::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new PanasonicProtocol(guiObject, index);
+
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
+  setPreData(0x2002, 16);
+
+  addPanasonicKey("vol up", VolumeUp_Key, 0xA0, 0x00, 0x20);
+  addPanasonicKey("vol down", VolumeDown_Key, 0xA0, 0x00, 0x21);
+  addPanasonicKey("balance", Unmapped_Key, 0xA0, 0x00, 0x26);
+  addPanasonicKey("side up", Unmapped_Key, 0xA0, 0x00, 0x2C);
+  addPanasonicKey("side down", Unmapped_Key, 0xA0, 0x00, 0x2D);
+  addPanasonicKey("s.st", Unmapped_Key, 0xA0, 0x00, 0x30);
+//  addPanasonicKey("sfc", Unmapped_Key, 0xA0, 0x00, 0x31); // also subdevice 0x14
+  addPanasonicKey("mute", Mute_Key, 0xA0, 0x00, 0x32);
+  addPanasonicKey("help", Unmapped_Key, 0xA0, 0x00, 0x39);
+  addPanasonicKey("power", Power_Key, 0xA0, 0x00, 0x3D); // also subdevice 0x04
+  addPanasonicKey("input toggle", Input_Key, 0xA0, 0x00, 0x80);
+  addPanasonicKey("tuner/band", TunerInput_Key, 0xA0, 0x00, 0x92);
+  addPanasonicKey("cd", CDInput_Key, 0xA0, 0x00, 0x94);
+  addPanasonicKey("tape", TapeInput_Key, 0xA0, 0x00, 0x96);
+  addPanasonicKey("vcr 1", VCRInput_Key, 0xA0, 0x00, 0x9E);
+  addPanasonicKey("tv", AntennaInput_Key, 0xA0, 0x00, 0x9F);
+  addPanasonicKey("dvd", DVDInput_Key, 0xA0, 0x00, 0xA3);
+  addPanasonicKey("input mode", Unmapped_Key, 0xA0, 0x00, 0xA8);
+  addPanasonicKey("s.srnd", Unmapped_Key, 0xA0, 0x00, 0xB2);
+  addPanasonicKey("source direct", Unmapped_Key, 0xA0, 0x00, 0xB7);
+  addPanasonicKey("remaster", Unmapped_Key, 0xA0, 0x00, 0xC8);
+  addPanasonicKey("center up", CenterVolumeUp_Key, 0xA0, 0x00, 0xCE);
+  addPanasonicKey("center down", CenterVolumeDown_Key, 0xA0, 0x00, 0xCF);
+  addPanasonicKey("subwoofer", Unmapped_Key, 0xA0, 0x00, 0xD5);
+  addPanasonicKey("doctor", Unmapped_Key, 0xA0, 0x00, 0xDF);
+  addPanasonicKey("test", Unmapped_Key, 0xA0, 0x00, 0xF6); // also 0x14
+
+  addPanasonicKey("1", One_Key, 0xA0, 0x04, 0x10);
+  addPanasonicKey("2", Two_Key, 0xA0, 0x04, 0x11);
+  addPanasonicKey("3", Three_Key, 0xA0, 0x04, 0x12);
+  addPanasonicKey("4", Four_Key, 0xA0, 0x04, 0x13);
+  addPanasonicKey("5", Five_Key, 0xA0, 0x04, 0x14);
+  addPanasonicKey("6", Six_Key, 0xA0, 0x04, 0x15);
+  addPanasonicKey("7", Seven_Key, 0xA0, 0x04, 0x16);
+  addPanasonicKey("8", Eight_Key, 0xA0, 0x04, 0x17);
+  addPanasonicKey("9", Nine_Key, 0xA0, 0x04, 0x18);
+  addPanasonicKey("0", Zero_Key, 0xA0, 0x04, 0x19);
+  addPanasonicKey("channel up", ChannelUp_Key, 0xA0, 0x04, 0x34);
+  addPanasonicKey("channel down", ChannelDown_Key, 0xA0, 0x04, 0x35);
+  addPanasonicKey("DicreteOn", PowerOn_Key, 0xA0, 0x04, 0x3E);
+  addPanasonicKey("DiscreteOff", PowerOff_Key, 0xA0, 0x04, 0x3F);
+  addPanasonicKey("10+", DoubleDigit_Key, 0xA0, 0x04, 0x84);
+  addPanasonicKey("tune +", Unmapped_Key, 0xA0, 0x04, 0x86);
+  addPanasonicKey("tune -", Unmapped_Key, 0xA0, 0x04, 0x87);
+  addPanasonicKey("direct tuning/disc", Unmapped_Key, 0xA0, 0x04, 0x88);
+  addPanasonicKey("band", Unmapped_Key, 0xA0, 0x04, 0xA4); // ?
+
+  addPanasonicKey("dvd 6ch", Unmapped_Key, 0xA0, 0x12, 0x8E);
+
+  addPanasonicKey("sfc", Unmapped_Key, 0xA0, 0x14, 0x31); // also subdevice 0x00
+  addPanasonicKey("level", Unmapped_Key, 0xA0, 0x14, 0x86);
+  addPanasonicKey("tone", Unmapped_Key, 0xA0, 0x14, 0x88);
+  addPanasonicKey("dimmer", Unmapped_Key, 0xA0, 0x14, 0x97);
+  addPanasonicKey("sound mode", SoundMode_Key, 0xA0, 0x14, 0xB0);
+  addPanasonicKey("dolby pro logic II", Unmapped_Key, 0xA0, 0x14, 0xB2);
+  addPanasonicKey("enhanced surround", Surround_Key, 0xA0, 0x14, 0xB3);
+  addPanasonicKey("neo:6", Unmapped_Key, 0xA0, 0x14, 0xB3);
+  addPanasonicKey("+r", BalanceRight_Key, 0xA0, 0x14, 0xBC); // "level +"
+  addPanasonicKey("-l", BalanceLeft_Key, 0xA0, 0x14, 0xBD); // "level -"
+  addPanasonicKey("select/enter", Select_Key, 0xA0, 0x14, 0xBE);
+  addPanasonicKey("level", Unmapped_Key, 0xA0, 0x14, 0xBE);
+  addPanasonicKey("effect", Unmapped_Key, 0xA0, 0x14, 0xBF);
+  addPanasonicKey("test", Unmapped_Key, 0xA0, 0x14, 0xF6); // also 0x00
+}
+
+
+void PanasonicAudio5::populateInputList(
+  QComboBox *cb) const
+{
+  cb->clear();
+
+  cb->addItem("Input Toggle", QVariant(Input_Key));
+  cb->addItem("Tuner Band Toggle", QVariant(TunerInput_Key));
+  cb->addItem("CD", QVariant(CDInput_Key));
+  cb->addItem("tape", QVariant(TapeInput_Key));
+  cb->addItem("vcr 1", QVariant(VCRInput_Key));
+  cb->addItem("tv", QVariant(AntennaInput_Key));
+  cb->addItem("dvd", QVariant(DVDInput_Key));
+}
+
+
+PanasonicAudio6::PanasonicAudio6(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "Audio Keyset 6",
+      Panasonic_Make,
+      Receiver_Panels,
+      index)
+{
+}
+
+
+void PanasonicAudio6::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new PanasonicProtocol(guiObject, index);
+
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
+  setPreData(0x2002, 16);
+
+  addPanasonicKey("Volume_Up", VolumeUp_Key, 0xA0, 0x00, 0x20);
+  addPanasonicKey("Volume_Down", VolumeDown_Key, 0xA0, 0x00, 0x21);
+  addPanasonicKey("InputAux", AuxInput_Key, 0xA0, 0x00, 0x9A);
+  addPanasonicKey("InputiPod", PCInput_Key, 0xA0, 0x00, 0x9B);
+  addPanasonicKey("InputCd/Dvd", CDInput_Key, 0xA0, 0x00, 0xA3);
+  addPanasonicKey("InputDigital", DigitalCoaxInput_Key, 0xA0, 0x00, 0xA8);
+  addPanasonicKey("DolbyPLII", Unmapped_Key, 0xA0, 0x00, 0xB4);
+  addPanasonicKey("Subwoofer", Unmapped_Key, 0xA0, 0x00, 0xD5);
+
+  addPanasonicKey("InputNext", Input_Key, 0xA0, 0x04, 0xA4);
+
+  addPanasonicKey("Sound", SoundMode_Key, 0xA0, 0x10, 0x83);
+
+  addPanasonicKey("1", One_Key, 0xA0, 0x1C, 0x10);
+  addPanasonicKey("2", Two_Key, 0xA0, 0x1C, 0x11);
+  addPanasonicKey("3", Three_Key, 0xA0, 0x1C, 0x12);
+  addPanasonicKey("4", Four_Key, 0xA0, 0x1C, 0x13);
+  addPanasonicKey("5", Five_Key, 0xA0, 0x1C, 0x14);
+  addPanasonicKey("6", Six_Key, 0xA0, 0x1C, 0x15);
+  addPanasonicKey("7", Seven_Key, 0xA0, 0x1C, 0x16);
+  addPanasonicKey("8", Eight_Key, 0xA0, 0x1C, 0x17);
+  addPanasonicKey("9", Nine_Key, 0xA0, 0x1C, 0x18);
+  addPanasonicKey("0", Zero_Key, 0xA0, 0x1C, 0x19);
+  addPanasonicKey("PowerToggle", Power_Key, 0xA0, 0x1C, 0x3D);
+  addPanasonicKey("PreviousTrack", Previous_Key, 0xA0, 0x1C, 0x49);
+  addPanasonicKey("NextTrack", Next_Key, 0xA0, 0x1C, 0x4A);
+  addPanasonicKey("FLDisplay", Unmapped_Key, 0xA0, 0x1C, 0x97);
+  addPanasonicKey("Start", Unmapped_Key, 0xA0, 0x1C, 0xAB);
+
+  addPanasonicKey("Stop", Stop_Key, 0xA0, 0x22, 0x00);
+  addPanasonicKey("Rewind", Rewind_Key, 0xA0, 0x22, 0x02);
+  addPanasonicKey("FastForward", FastForward_Key, 0xA0, 0x22, 0x03);
+  addPanasonicKey("Pause", Pause_Key, 0xA0, 0x22, 0x06);
+  addPanasonicKey("Play", Play_Key, 0xA0, 0x22, 0x0A);
+  addPanasonicKey("DirectionUp", Up_Key, 0xA0, 0x22, 0x34);
+  addPanasonicKey("DirectionDown", Down_Key, 0xA0, 0x22, 0x35);
+  addPanasonicKey("DirectionRight", Right_Key, 0xA0, 0x22, 0x36);
+  addPanasonicKey("DirectionLeft", Left_Key, 0xA0, 0x22, 0x37);
+  addPanasonicKey("Repeat", Repeat_Key, 0xA0, 0x22, 0x47);
+  addPanasonicKey("Functions", Unmapped_Key, 0xA0, 0x22, 0x57);
+  addPanasonicKey("OneTouchPlay", Unmapped_Key, 0xA0, 0x22, 0x5A);
+  addPanasonicKey("Cancel", Exit_Key, 0xA0, 0x22, 0x80);
+  addPanasonicKey("Sleep", Sleep_Key, 0xA0, 0x22, 0x8E);
+  addPanasonicKey("DiscSelect", NextDisc_Key, 0xA0, 0x22, 0xA4);
+  addPanasonicKey("TopMenu", DiscTitle_Key, 0xA0, 0x22, 0xAB);
+  addPanasonicKey("Setup", Menu_Key, 0xA0, 0x22, 0xB5);
+  addPanasonicKey("PlayMode", Unmapped_Key, 0xA0, 0x22, 0xBB);
+  addPanasonicKey("Menu", DiscMenu_Key, 0xA0, 0x22, 0xC0);
+  addPanasonicKey("Return", Exit_Key, 0xA0, 0x22, 0xC4);
+  addPanasonicKey("Select/Ok", Select_Key, 0xA0, 0x22, 0xC6);
+}
+
+
+void PanasonicAudio6::populateInputList(
+  QComboBox *cb) const
+{
+  cb->clear();
+
+  cb->addItem("Input Toggle", QVariant(Input_Key));
+  cb->addItem("Aux", QVariant(AuxInput_Key));
+  cb->addItem("iPod", QVariant(PCInput_Key));
+  cb->addItem("CD / DVD", QVariant(CDInput_Key));
+  cb->addItem("Digital", QVariant(DigitalCoaxInput_Key));
+}
+
+
 PanasonicAC1::PanasonicAC1(
   unsigned int index)
   : PIRKeysetMetaData(
