@@ -268,6 +268,51 @@ public:
     QComboBox *cb) const;
 };
 
+class PanasonicAudio4: public PIRKeysetMetaData
+{
+  Q_OBJECT
+
+public:
+  PanasonicAudio4(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+
+  virtual void populateInputList(
+    QComboBox *cb) const;
+};
+
+class PanasonicAudio5: public PIRKeysetMetaData
+{
+  Q_OBJECT
+
+public:
+  PanasonicAudio5(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+
+  virtual void populateInputList(
+    QComboBox *cb) const;
+};
+
+class PanasonicAudio6: public PIRKeysetMetaData
+{
+  Q_OBJECT
+
+public:
+  PanasonicAudio6(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+
+  virtual void populateInputList(
+    QComboBox *cb) const;
+};
+
 class PanasonicAC1: public PIRKeysetMetaData
 {
   Q_OBJECT
