@@ -221,6 +221,8 @@ PIRKeynameMgr::PIRKeynameMgr()
   keynameStrings[FanFaster_Key] = "Fan Faster";
   keynameStrings[FanSlower_Key] = "Fan Slower";
   keynameStrings[EnergySave_Key] = "Energy Save Mode";
+  keynameStrings[StepLouverVertical_Key] = "Step Louver Vertical";
+  keynameStrings[StepLouverHorizontal_Key] = "Step Louver Horizontal";
   keynameStrings[ACSendCommand_Key] = "Send Stateful AC Command";
   keynameStrings[ACSetTimer_Key] = "Set AC Timer";
   keynameStrings[RobotForward_Key] = "Robot Forward";
