@@ -260,6 +260,8 @@ enum PIRKeyName
   FanFaster_Key,
   FanSlower_Key,
   EnergySave_Key, // Also used for TVs with E-save mode!
+  StepLouverVertical_Key,
+  StepLouverHorizontal_Key,
 
   // Stateful A/C controls:
   ACSendCommand_Key,
