@@ -426,7 +426,7 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new FrontechTV1(++counter));
   setupKeyset(new FrontechTV2(++counter));
 
-//  setupKeyset(new FujitsuAC1(++counter));
+  setupKeyset(new FujitsuAC1(++counter));
 
   setupKeyset(new GadmeiTuner1(++counter));
 
@@ -460,6 +460,8 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new GrundigTV2(++counter));
   setupKeyset(new GrundigTV3(++counter));
   setupKeyset(new GrundigTV4(++counter));
+  setupKeyset(new GrundigTV5(++counter));
+  setupKeyset(new GrundigTV6(++counter));
   setupKeyset(new GrundigDVD1(++counter));
 
   setupKeyset(new HaierTV1(++counter));
@@ -716,6 +718,10 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new PanasonicAudio1(++counter));
   setupKeyset(new PanasonicAudio2(++counter));
   setupKeyset(new PanasonicAudio2a(++counter));
+  setupKeyset(new PanasonicAudio3(++counter));
+  setupKeyset(new PanasonicAudio4(++counter));
+  setupKeyset(new PanasonicAudio5(++counter));
+  setupKeyset(new PanasonicAudio6(++counter));
   setupKeyset(new PanasonicAC1(++counter));
 
   setupKeyset(new PentaxCamera1(++counter));
